@@ -31,7 +31,7 @@ export_srt <- function(t,
 					   speaker.width=3,
 					   speaker.ending=":") {
 	
-	if (missing(t)) 	{stop("Transcript object in parameter 't' is missing.") 	} else { if (class(t)[[1]]!="transcript") 	{stop("Parameter 't' needs to be a transcript object.") 	} }
+	if (missing(t)) 	{stop("Transcript object in parameter 't' is missing.") 	}	else { if (!methods::is(t, "transcript")) 	{stop("Parameter 't' needs to be a transcript object.") 	} }
 	
 	#--- check if output folder exists
 	if (!is.null(outputPath)) {
