@@ -7,8 +7,8 @@
 #' - Time values of annotations in TextGrids may be below 0 seconds. Negative time values will be recognized corretly in the first place. When exporting transcript object to other formats like 'ELAN' .eaf, 'EXMARaLDA' .exb ect. annotations that are completely before 0 sec will be deleted, annotations that start before but end after 0 sec will be truncated. Please see also the function \code{act::transcripts_cure_single}.  
 #' - TextGrids and contained tiers may start and end at different times. These times do not need to match each other. The act package does not support start and end times of TextGrids and tiers and will. The default start of a TextGrid will be 0 seconds or the lowest value in case that annotations start below 0 seconds.
 #' 
-#' Credits to Tomáš Bořil, the author of the rPraat package, for commenting on the exchange functions.
-#'
+#' Credits: Thanks to Tomáš Bořil, the author of the rPraat package, for commenting on the exchange functions.
+#' 
 #' @param rPraatTextGrid List; rPraat TextGrid object.
 #' @param transcriptName Character string; name of the transcript.
 #' 
@@ -42,10 +42,10 @@ import_rpraat <- function(rPraatTextGrid,
 		t@name				<- stringr::str_replace(attr(rPraatTextGrid, "class")["name"], ".TextGrid","")
 	}
 	t@file.type 			 <- "rpraat"
-	t@import.result 		     <- "ok"
+	t@import.result 		 <- "ok"
 	t@load.message    	     <- ""
 	t@modification.systime   <- character()
-	t@length				 <- as.double(attr(rPraatTextGrid, "class")["tmax"])
+	t@length.sec        	 <- as.double(attr(rPraatTextGrid, "class")["tmax"])
 	if(getOption("act.import.storeFileContentInTranscript", default=TRUE)) {
 		t@file.content <- rPraatTextGrid
 	}
