@@ -40,8 +40,8 @@ media_assign <- function(x,
 	#onlyUniqueFiles    <- TRUE
 	
 	
-	if (missing(x)) 	{stop("Corpus object in parameter 'x' is missing.") 		} else { if (class(x)[[1]]!="corpus") 		{stop("Parameter 'x' needs to be a corpus object.") 	} }
-
+	if (missing(x)) 	{stop("Corpus object in parameter 'x' is missing.") 		}	else { if (!methods::is(x,"corpus")   )	{stop("Parameter 'x' needs to be a corpus object.") } }
+	
 	message <- c()
 
 	if (is.null(searchPaths)) {
